==> isis-fish-4.2.0.1-sources.jar: fr/ifremer/isisfish/ui/input/tree/loadors/FisheryTreeNodeLoador.java <==
/*
 * #%L
 * $Id: FisheryTreeNodeLoador.java 3348 2011-06-05 14:34:08Z chatellier $
 * $HeadURL: http://svn.forge.codelutin.com/svn/isis-fish/tags/isis-fish-4.2.0.1/src/main/java/fr/ifremer/isisfish/ui/input/tree/loadors/FisheryTreeNodeLoador.java $
 * %%
 * Copyright (C) 2011 Ifremer, Codelutin, Chatellier Eric
 * %%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as
 * published by the Free Software Foundation, either version 2 of the 
 * License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public 
 * License along with this program.  If not, see
 * <http://www.gnu.org/licenses/gpl-2.0.html>.
 * #L%
 */

package fr.ifremer.isisfish.ui.input.tree.loadors;

import jaxx.runtime.swing.nav.tree.NavTreeNodeChildLoador;

import org.nuiton.topia.persistence.TopiaEntity;

import fr.ifremer.isisfish.ui.input.tree.FisheryTreeNode;

/**
 * Common class to all loador.
 * 
 * @author chatellier
 * @version $Revision: 3348 $
 * 
 * Last update : $Date: 2011-06-05 16:34:08 +0200 (Sun, 05 Jun 2011) $
 * By : $Author: chatellier $
 * @param <T> 
 */
public abstract class FisheryTreeNodeLoador<T extends TopiaEntity> extends NavTreeNodeChildLoador<T, T, FisheryTreeNode> {

    /** serialVersionUID. */
    private static final long serialVersionUID = 7738607604066405224L;

    public FisheryTreeNodeLoador(Class<T> type) {
        super(type);
    }
}

==> isis-fish-4.3.0.0-sources.jar: fr/ifremer/isisfish/ui/input/tree/loadors/FisheryTreeNodeLoador.java <==
/*
 * #%L
 * $Id: FisheryTreeNodeLoador.java 3798 2012-10-30 10:39:32Z echatellier $
 * $HeadURL: https://svn.codelutin.com/isis-fish/tags/isis-fish-4.3.0.0/src/main/java/fr/ifremer/isisfish/ui/input/tree/loadors/FisheryTreeNodeLoador.java $
 * %%
 * Copyright (C) 2011 Ifremer, Codelutin, Chatellier Eric
 * %%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as
 * published by the Free Software Foundation, either version 3 of the 
 * License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public 
 * License along with this program.  If not, see
 * <http://www.gnu.org/licenses/gpl-3.0.html>.
 * #L%
 */

package fr.ifremer.isisfish.ui.input.tree.loadors;

import jaxx.runtime.swing.nav.tree.NavTreeNodeChildLoador;

import org.nuiton.topia.persistence.TopiaEntity;

import fr.ifremer.isisfish.ui.input.tree.FisheryTreeNode;

/**
 * Common class to all loador.
 * 
 * @author chatellier
 * @version $Revision: 3798 $
 * 
 * Last update : $Date: 2012-10-30 11:39:32 +0100 (Tue, 30 Oct 2012) $
 * By : $Author: echatellier $
 * @param <T> 
 */
public abstract class FisheryTreeNodeLoador<T extends TopiaEntity> extends NavTreeNodeChildLoador<T, T, FisheryTreeNode> {

    /** serialVersionUID. */
    private static final long serialVersionUID = 7738607604066405224L;

    public FisheryTreeNodeLoador(Class<T> type) {
        super(type);
    }
}
